/**
 * vue-inertia-composable
 *
 * @description Inertia for Vue2 Composition API.
 * @author Logue <logue@hotmail.co.jp>
 * @copyright 2022-2023 By Masashi Yoshikawa All rights reserved.
 * @license MIT
 * @version 0.4.3
 * @see {@link https://github.com/logue/vue-inertia-composable}
 */

(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('vue-demi'), require('ziggy-js'), require('@inertiajs/vue2'), require('@inertiajs/inertia')) :
  typeof define === 'function' && define.amd ? define(['exports', 'vue-demi', 'ziggy-js', '@inertiajs/vue2', '@inertiajs/inertia'], factory) :
  (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.InertiaComposable = {}, global.VueDemi, global.ziggy, global.InertiaVue2, global.Inertia));
})(this, (function (exports, vueDemi, ziggy, vue2, inertia) { 'use strict';

  const InertiaLink = vueDemi.defineComponent({
    name: "InertiaLink",
    props: {
      as: {
        type: String,
        default: "a"
      },
      href: {
        type: String,
        default: (typeof document === 'undefined' && typeof location === 'undefined' ? new (require('u' + 'rl').URL)('file:' + __filename).href : typeof document === 'undefined' ? location.href : (document.currentScript && document.currentScript.src || new URL('index.umd.js', document.baseURI).href))
      },
      method: {
        type: String,
        default: "get"
      },
      data: {
        type: Object,
        default: () => {
          return {};
        }
      },
      replace: {
        type: Boolean,
        default: false
      },
      preserveScroll: {
        type: Boolean,
        default: false
      },
      preserveState: {
        type: Boolean,
        default: false
      },
      only: {
        type: Array,
        default: () => {
          return [];
        }
      },
      headers: {
        type: Object,
        default: () => () => {
          return {};
        }
      },
      errorBag: {
        type: String,
        default: ""
      },
      forceFormData: {
        type: Boolean,
        default: false
      },
      queryStringArrayFormat: {
        type: String,
        default: "brackets"
      }
    },
    render() {
      const as = this.$props.as.toLowerCase() || "a";
      const method = this.$props.method.toLocaleLowerCase() || "get";
      const attrs = this.$attrs;
      const [href, data] = inertia.mergeDataIntoQueryString(
        method,
        this.$props.href,
        this.$props.data,
        this.$props.queryStringArrayFormat
      );
      if (as === "a" && method !== "get") {
        console.warn(
          `Creating POST/PUT/PATCH/DELETE <a> links is discouraged as it causes "Open Link in New Tab/Window" accessibility issues.

Please specify a more appropriate element using the "as" attribute. For example:

<inertia-link href="${href}" method="${method}" as="button">...</inertia-link>`
        );
      }
      return vueDemi.h(
        as,
        {
          ...this.$attrs,
          ...as === "a" ? { href } : {},
          // @ts-ignore
          onClick: (event) => {
            event.preventDefault();
            if (!inertia.shouldIntercept(event)) {
              return;
            }
            inertia.Inertia.visit(href, {
              method,
              data,
              replace: this.$props.replace,
              preserveScroll: this.$props.preserveScroll,
              preserveState: this.$props.preserveState ?? method !== "get",
              only: this.$props.only,
              headers: this.$props.headers,
              errorBag: this.$props.errorBag,
              forceFormData: this.$props.forceFormData,
              onCancelToken: attrs.onCancelToken || (() => void 0),
              onBefore: attrs.onBefore || (() => void 0),
              onStart: attrs.onStart || (() => void 0),
              onProgress: attrs.onProgress || (() => void 0),
              onFinish: attrs.onFinish || (() => void 0),
              onCancel: attrs.onCancel || (() => void 0),
              onSuccess: attrs.onSuccess || (() => void 0),
              onError: attrs.onError || (() => void 0)
            });
          }
        },
        this.$slots.default
      );
    }
  });
  const installInertiaLink = (app) => app.component("InertiaLink", InertiaLink);
  if (typeof window !== "undefined" && window.Vue) {
    window.Vue.use(InertiaLink);
  }

  function useHeadManager() {
    const instance = vueDemi.getCurrentInstance();
    if (instance) {
      return instance.proxy.$headManager;
    } else {
      warn();
    }
    return void 0;
  }
  function usePage() {
    const instance = vueDemi.getCurrentInstance();
    if (instance) {
      return instance.proxy.$page;
    }
    return vue2.usePage();
  }
  function useInertia() {
    const instance = vueDemi.getCurrentInstance();
    if (instance) {
      return instance.proxy.$inertia;
    } else {
      warn();
    }
    return void 0;
  }
  function useForm(rememberKey, data) {
    const instance = vueDemi.getCurrentInstance();
    if (rememberKey) {
      return instance ? (
        // @ts-ignore
        instance.proxy.$inertia.form(rememberKey, data)
      ) : vue2.useForm(rememberKey, data);
    }
    return instance ? (
      // @ts-ignore
      instance.proxy.$inertia.form(data)
    ) : vue2.useForm(data);
  }
  function route(name, params, absolute, config) {
    const instance = vueDemi.getCurrentInstance();
    if (instance && instance.proxy.route) {
      return instance.proxy.route(name, params, absolute, config);
    }
    return ziggy(name, params, absolute, config);
  }
  const warn = () => console.warn(
    `[Inertia Composable] getCurrentInstance() returned null. Method must be called at the top of a setup() function.`
  );
  if (typeof window !== "undefined") {
    window.route = route;
  }

  exports.InertiaLink = InertiaLink;
  exports.install = installInertiaLink;
  exports.route = route;
  exports.useForm = useForm;
  exports.useHeadManager = useHeadManager;
  exports.useInertia = useInertia;
  exports.usePage = usePage;

  Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });

}));
